developerscripttools.CountToolsScript
=====================================

.. inheritance-diagram:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.alias

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.process_args

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
